import { Cell } from 'vant'
import { defineComponent, PropType } from 'vue'
import styles from './index.module.less'

// import QrCodeVue from 'qrcode.vue'
// import { toPng } from 'html-to-image'

import iconTeacher from '@/common/images/icon_teacher.png'
import { state } from '@/state'
import CodeDownload from './code-down-load'

export const getAssetsHomeFile = (fileName: string) => {
  const path = `./images/${fileName}`
  const modules = import.meta.globEager('./images/*')
  return modules[path].default
}

export default defineComponent({
  name: 'share-item',
  props: {
    teacherId: {
      type: Number
    },
    shareUrl: {
      type: String,
      default: ''
    },
    showType: {
      // 显示背景图
      type: String as PropType<'yellow' | 'pink' | ''>,
      default: ''
    },
    shareType: {
      // 分享类型
      type: String as PropType<'' | 'video' | 'music' | 'live'>,
      default: ''
    }
  },
  render() {
    return (
      <div
        class={[
          styles.shareSection,
          styles.shareContainer,
          styles[this.showType]
        ]}
        id="share-preview-container"
      >
        <div class={styles.shareTitle}>
          <p class={styles.title}>
            优秀的老师能帮助
            <br />
            您快速成长
          </p>
          <p class={styles.titleTip}>在知识中温故知新，熟能生巧</p>
        </div>

        {this.$slots.default && this.$slots.default()}

        <Cell
          center
          border={false}
          class={styles.shareTeacher}
          v-slots={{
            icon: () => (
              <div class={styles.teacherImg}>
                <img
                  src={
                    state.user.data.heardUrl
                      ? state.user.data.heardUrl +
                        '?time=' +
                        new Date().valueOf()
                      : iconTeacher
                  }
                  class={styles.img}
                  crossorigin="anonymous"
                />
                <img
                  class={styles.recommend}
                  src={getAssetsHomeFile('recommend.png')}
                />
              </div>
            ),
            title: () => (
              <div>
                <p class={styles.name}>这套课程挺不错！推荐给你～</p>
                <p class={styles.titleTips}>
                  <span>{state.user.data.username}</span>
                  酷乐秀入驻老师
                </p>
              </div>
            )
          }}
        />

        <CodeDownload shareUrl={this.shareUrl} />
      </div>
    )
  }
})
