import CourseVideoItem from '@/business-components/course-video-item'
import SectionDetail from '@/business-components/section-detail'
import UserDetail from '@/business-components/user-detail'
import { Button, Toast } from 'vant'
import { defineComponent } from 'vue'
import styles from './index.module.less'
import request from '@/helpers/request'
import ColSticky from '@/components/col-sticky'

export const getAssetsHomeFile = (fileName: string) => {
  const path = `../images/${fileName}`
  const modules = import.meta.globEager('./images/*')
  return modules[path].default
}

export default defineComponent({
  name: 'VideoDetail',
  data() {
    const query = this.$route.query
    return {
      userInfo: {} as any,
      detailList: [],
      buyUserList: [], // 购买学生数
      dataShow: true, // 判断是否有数据
      loading: false,
      finished: false,
      recomUserId: query.recomUserId, // 分享人编号
      params: {
        videoLessonGroupId: query.groupId,
        page: 1,
        rows: 20
      },
      wxStatus: false
    }
  },
  async mounted() {
    try {
      const res = await request.post(`/api-teacher//open/videoShareProfit`, {
        data: {
          bizId: this.params.videoLessonGroupId,
          userId: this.recomUserId
        }
      })
      const result = res.data || {}
      console.log(result)
      const { lessonGroup, detailList } = result.videoGroup
      this.userInfo = {
        username: result.name,
        headUrl: result.avatar,
        buyNum: lessonGroup.countStudent,
        lessonNum: lessonGroup.lessonCount,
        lessonName: lessonGroup.lessonName,
        lessonDesc: lessonGroup.lessonDesc,
        lessonPrice: lessonGroup.lessonPrice,
        lessonCoverUrl: lessonGroup.lessonCoverUrl
      }

      this.detailList = detailList || []

      this.getList()
    } catch {
      //
    }
  },
  methods: {
    async getList() {
      try {
        const params = this.params
        const res = await request.post('/api-teacher/videoLesson/pageStudent', {
          data: {
            ...params
          }
        })
        this.loading = false
        const result = res.data || {}
        // 处理重复请求数据
        if (this.buyUserList.length > 0 && result.pageNo === 1) {
          return
        }
        this.buyUserList = this.buyUserList.concat(result.rows || [])
        this.finished = result.pageNo >= result.totalPage
        this.params.page = result.pageNo + 1
        this.dataShow = this.buyUserList.length > 0
      } catch {
        this.dataShow = false
        this.finished = true
      }
    },
    onPlay(detail: any) {
      this.$router.push({
        path: '/videoClassDetail',
        query: {
          groupId: this.params.videoLessonGroupId,
          classId: detail.id
        }
      })
    },

    onShare() {
      const { origin, pathname } = location
      let str = origin + '/#/videoDetail'
      const params = this.$route.query
      str += `?recomUserId=${this.recomUserId}&groupId=${params.groupId}`

      const query = {
        url: str,
        action: params.action || 'h5', // app, h5
        pageTag: params.pageTag || 1, // 页面标识
        params: {}
      }
      alert(str)
      const iosStr = encodeURIComponent(JSON.stringify(query))
      if (/(iPhone|iPad|iPod|iOS)/i.test(navigator.userAgent)) {
        // ColexiuStudent 唤起学生端
        window.location.href = `ColexiuStudent://linkUrl=${iosStr}`
      } else if (/(Android)/i.test(navigator.userAgent)) {
        window.location.href = `colexiustudent://html:8888/SplashActivity?url=${JSON.stringify(
          query
        )}`
      } else {
        Toast('请用手机或移动设备打开')
      }
    }
  },
  render() {
    return (
      <div class={[styles['video-detail'], 'mb12']}>
        <UserDetail userInfo={this.userInfo} />
        <SectionDetail border>
          <p class={styles.introduction}>{this.userInfo.lessonDesc}</p>
        </SectionDetail>

        <SectionDetail
          title="课程列表"
          icon="courseList"
          contentStyle={{ paddingTop: '0' }}
        >
          {this.detailList.map((item: any) => (
            <CourseVideoItem
              class={'mb12'}
              detail={{
                id: item.id,
                title: item.videoTitle,
                content: item.videoContent,
                imgUrl: item.coverUrl
              }}
              onPlay={this.onPlay}
            />
          ))}
        </SectionDetail>

        <ColSticky position="bottom">
          <div class={['btnGroup']} style={{ paddingTop: '12px' }}>
            <Button block round type="primary" onClick={this.onShare}>
              下载酷乐秀进入课程
            </Button>
          </div>
        </ColSticky>

        {this.wxStatus && (
          <div
            class={styles.wxpopup}
            onClick={() => {
              this.wxStatus = false
            }}
          >
            <img src={getAssetsHomeFile('wx_bg.png')} alt="" />
          </div>
        )}
      </div>
    )
  }
})
